@@ -1,4 +1,4 @@
-class PopulateEnumerationsPositionName < ActiveRecord::Migration
+class PopulateEnumerationsPositionName < ActiveRecord::Migration[4.2]
   def up
     IssuePriority.compute_position_names
   end
