@@ -20,12 +20,6 @@
 require_relative '../test_helper'
 
 class MyControllerTest < Redmine::ControllerTest
-  fixtures :users, :email_addresses, :user_preferences,
-           :roles, :projects, :members, :member_roles,
-           :issues, :issue_statuses, :trackers, :enumerations,
-           :custom_fields, :auth_sources, :queries, :enabled_modules,
-           :journals, :projects_trackers, :issue_categories
-
   def setup
     @request.session[:user_id] = 2
   end
@@ -605,6 +599,7 @@ class MyControllerTest < Redmine::ControllerTest
   def test_change_password
     get :password
     assert_response :success
+    assert_includes @response.headers['Cache-Control'], 'no-store'
     assert_select 'input[type=password][name=password][autocomplete=current-password]'
     assert_select 'input[type=password][name=new_password][autocomplete=new-password]'
     assert_select 'input[type=password][name=new_password_confirmation][autocomplete=new-password]'
